aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorJim Borden <jim.borden@couchbase.com>2021-09-09 11:32:40 +0900
committerWireshark GitLab Utility <gerald+gitlab-utility@wireshark.org>2021-09-09 06:38:46 +0000
commitcb88f6d4e8b9c5d419034351c5bf28aba62ce3bd (patch)
treef6179c34d40d9faad2fd3115be767fc3d55c4fb9 /epan
parent42372c0dfa2ffd3ef91da4c810df4bef521dd85e (diff)
BLIP: Add next gen Web-Sec-Protocol
Starting with 3.0 there is a new non backwards compatible Web-Sec-Protocol for BLIP, so the plugin should handle both (the differences are irrelevant from Wireshark's standpoint)
Diffstat (limited to 'epan')
-rw-r--r--epan/dissectors/packet-blip.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/epan/dissectors/packet-blip.c b/epan/dissectors/packet-blip.c
index bfd235ef3f..3b21fcf3fa 100644
--- a/epan/dissectors/packet-blip.c
+++ b/epan/dissectors/packet-blip.c
@@ -622,11 +622,13 @@ proto_reg_handoff_blip(void)
{
// Register the blip dissector as a subprotocol dissector of "ws.protocol",
// matching any packets with a Web-Sec-Protocol header of "BLIP_3+CBMobile_2".
//
// See https://github.com/couchbase/sync_gateway/issues/3356#issuecomment-370958321 for
// more notes on how the websocket dissector routes packets down to subprotocol handlers.
+ dissector_add_string("ws.protocol", "BLIP_3+CBMobile_3", blip_handle);
dissector_add_string("ws.protocol", "BLIP_3+CBMobile_2", blip_handle);
}
@@ -622,11 +622,13 @@ proto_reg_handoff_blip(void)
{
// Register the blip dissector as a subprotocol dissector of "ws.protocol",
- // matching any packets with a Web-Sec-Protocol header of "BLIP_3+CBMobile_2".
+ // matching any packets with a Web-Sec-Protocol header of "BLIP_3+CBMobile_2"
+ // or "BLIP_3+CBMobile_3"
//
// See https://github.com/couchbase/sync_gateway/issues/3356#issuecomment-370958321 for